@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.modules
 r"""
 Quantum Clifford Algebras
 
@@ -29,6 +30,7 @@ from sage.sets.finite_enumerated_set import FiniteEnumeratedSet
 from itertools import product
 from sage.combinat.subset import powerset
 
+
 class QuantumCliffordAlgebra(CombinatorialFreeModule):
     r"""
     The quantum Clifford algebra.
@@ -288,18 +290,18 @@ class QuantumCliffordAlgebra(CombinatorialFreeModule):
         for i in range(self._n):
             r = list(zero)  # Make a copy
             r[i] = 1
-            d['psi%s'%i] = self.monomial( (self._psi(r), one) )
+            d['psi%s' % i] = self.monomial((self._psi(r), one))
             r[i] = -1
-            d['psid%s'%i] = self.monomial( (self._psi(r), one) )
+            d['psid%s' % i] = self.monomial((self._psi(r), one))
         zero = self._psi(zero)
         for i in range(self._n):
             temp = list(zero)  # Make a copy
             temp[i] = 1
-            d['w%s'%i] = self.monomial( (zero, tuple(temp)) )
+            d['w%s' % i] = self.monomial((zero, tuple(temp)))
         return Family(sorted(d), lambda i: d[i])
 
     @cached_method
-    def gens(self):
+    def gens(self) -> tuple:
         r"""
         Return the generators of ``self``.
 
@@ -324,6 +326,7 @@ class QuantumCliffordAlgebra(CombinatorialFreeModule):
         """
         return (self._psi([0]*self._n), (0,)*self._n)
 
+
 class QuantumCliffordAlgebraGeneric(QuantumCliffordAlgebra):
     r"""
     The quantum Clifford algebra when `q^{2k} \neq 1`.
@@ -397,10 +400,10 @@ class QuantumCliffordAlgebraGeneric(QuantumCliffordAlgebra):
             5
         """
         p, v = m
-        rp = '*'.join('psi%s'%i if p[i] > 0 else 'psid%s'%i
+        rp = '*'.join('psi%s' % i if p[i] > 0 else 'psid%s' % i
                       for i in range(self._n) if p[i] != 0)
-        gen_str = lambda e: '' if e == 1 else '^%s'%e
-        rv = '*'.join('w%s'%i + gen_str(v[i]) for i in range(self._n) if v[i] != 0)
+        gen_str = lambda e: '' if e == 1 else '^%s' % e
+        rv = '*'.join('w%s' % i + gen_str(v[i]) for i in range(self._n) if v[i] != 0)
         if rp:
             if rv:
                 return rp + '*' + rv
@@ -429,10 +432,10 @@ class QuantumCliffordAlgebraGeneric(QuantumCliffordAlgebra):
             5
         """
         p, v = m
-        rp = ''.join('\\psi_{%s}'%i if p[i] > 0 else '\\psi^{\\dagger}_{%s}'%i
+        rp = ''.join('\\psi_{%s}' % i if p[i] > 0 else '\\psi^{\\dagger}_{%s}' % i
                      for i in range(self._n) if p[i] != 0)
-        gen_str = lambda e: '' if e == 1 else '^{%s}'%e
-        rv = ''.join('\\omega_{%s}'%i + gen_str(v[i])
+        gen_str = lambda e: '' if e == 1 else '^{%s}' % e
+        rv = ''.join('\\omega_{%s}' % i + gen_str(v[i])
                      for i in range(self._n) if v[i] != 0)
         if not rp and not rv:
             return '1'
@@ -486,7 +489,7 @@ class QuantumCliffordAlgebraGeneric(QuantumCliffordAlgebra):
                 if p1[i] != 0:
                     # We make pairings 1-based because we cannot distinguish 0 and -0
                     pairings.append((i+1) * p1[i])
-            # we know p1[i] != p2[i] if non-zero, so their sum is -1, 0, 1
+            # we know p1[i] != p2[i] if nonzero, so their sum is -1, 0, 1
             p[i] = p1[i] + p2[i]
 
         supported.append(self._n-1) # To get between the last support and the end
@@ -530,7 +533,7 @@ class QuantumCliffordAlgebraGeneric(QuantumCliffordAlgebra):
         poly *= self._w_poly.monomial(*v)
         poly = poly.reduce([vp[i]**(4*k) - (1 + q**(-2*k)) * vp[i]**(2*k) + q**(-2*k)
                             for i in range(self._n)])
-        pdict = poly.dict()
+        pdict = poly.monomial_coefficients()
         ret = {(self._psi(p), tuple(e)): pdict[e] * q**q_power * sign
                for e in pdict}
 
@@ -607,13 +610,14 @@ class QuantumCliffordAlgebraGeneric(QuantumCliffordAlgebra):
                               for wi in wp})
             poly = poly.reduce([wi**(4*k) - (1 + q**(-2*k)) * wi**(2*k) + q**(-2*k)
                                 for wi in wp])
-            pdict = poly.dict()
+            pdict = poly.monomial_coefficients()
             coeff = coeff.inverse_of_unit()
             ret = {(p, tuple(e)): coeff * c for e, c in pdict.items()}
             return Cl.element_class(Cl, ret)
 
         __invert__ = inverse
 
+
 class QuantumCliffordAlgebraRootUnity(QuantumCliffordAlgebra):
     r"""
     The quantum Clifford algebra when `q^{2k} = 1`.
@@ -700,15 +704,15 @@ class QuantumCliffordAlgebraRootUnity(QuantumCliffordAlgebra):
         def ppr(i):
             val = p[i]
             if val == -1:
-                return 'psid%s'%i
+                return 'psid%s' % i
             elif val == 1:
-                return 'psi%s'%i
+                return 'psi%s' % i
             elif val == 2:
-                return 'psi%s*psid%s'%(i,i)
+                return 'psi%s*psid%s' % (i,i)
 
         rp = '*'.join(ppr(i) for i in range(self._n) if p[i] != 0)
-        gen_str = lambda e: '' if e == 1 else '^%s'%e
-        rv = '*'.join('w%s'%i + gen_str(v[i]) for i in range(self._n) if v[i] != 0)
+        gen_str = lambda e: '' if e == 1 else '^%s' % e
+        rv = '*'.join('w%s' % i + gen_str(v[i]) for i in range(self._n) if v[i] != 0)
         if rp:
             if rv:
                 return rp + '*' + rv
@@ -741,15 +745,15 @@ class QuantumCliffordAlgebraRootUnity(QuantumCliffordAlgebra):
         def ppr(i):
             val = p[i]
             if val == -1:
-                return '\\psi^{\\dagger}_{%s}'%i
+                return '\\psi^{\\dagger}_{%s}' % i
             elif val == 1:
-                return '\\psi_{%s}'%i
+                return '\\psi_{%s}' % i
             elif val == 2:
                 return '\\psi_{%s}\\psi^{\\dagger}_{%s}' % (i, i)
 
         rp = ''.join(ppr(i) for i in range(self._n) if p[i] != 0)
-        gen_str = lambda e: '' if e == 1 else '^{%s}'%e
-        rv = ''.join('\\omega_{%s}'%i + gen_str(v[i])
+        gen_str = lambda e: '' if e == 1 else '^{%s}' % e
+        rv = ''.join('\\omega_{%s}' % i + gen_str(v[i])
                      for i in range(self._n) if v[i] != 0)
         if not rp and not rv:
             return '1'
@@ -875,7 +879,7 @@ class QuantumCliffordAlgebraRootUnity(QuantumCliffordAlgebra):
             return (self._psi(p), tuple(e))
 
         q = self._q
-        ret = {key(X): (-1)**len(X) * sign * q**(q_power+k*(len(pairings)%2))
+        ret = {key(X): (-1)**len(X) * sign * q**(q_power+k*(len(pairings) % 2))
                for X in powerset(pairings)}
 
         return self._from_dict(ret)
