@@ -33,14 +33,14 @@ class ContourPlot(GraphicPrimitive):
 
     INPUT:
 
-    - ``xy_data_array`` - list of lists giving evaluated values of the function
+    - ``xy_data_array`` -- list of lists giving evaluated values of the function
       on the grid
 
-    - ``xrange`` - tuple of 2 floats indicating range for horizontal direction
+    - ``xrange`` -- tuple of 2 floats indicating range for horizontal direction
 
-    - ``yrange`` - tuple of 2 floats indicating range for vertical direction
+    - ``yrange`` -- tuple of 2 floats indicating range for vertical direction
 
-    - ``options`` - dict of valid plot options to pass to constructor
+    - ``options`` -- dictionary of valid plot options to pass to constructor
 
     EXAMPLES:
 
@@ -242,19 +242,19 @@ def contour_plot(f, xrange, yrange, **options):
 
     - ``f`` -- a function of two variables
 
-    - ``(xmin,xmax)`` -- 2-tuple, the range of ``x`` values OR 3-tuple
+    - ``(xmin, xmax)`` -- 2-tuple, the range of ``x`` values OR 3-tuple
       ``(x,xmin,xmax)``
 
-    - ``(ymin,ymax)`` -- 2-tuple, the range of ``y`` values OR 3-tuple
+    - ``(ymin, ymax)`` -- 2-tuple, the range of ``y`` values OR 3-tuple
       ``(y,ymin,ymax)``
 
     The following inputs must all be passed in as named parameters:
 
-    - ``plot_points``  -- integer (default: 100); number of points to plot
+    - ``plot_points`` -- integer (default: 100); number of points to plot
       in each direction of the grid.  For old computers, 25 is fine, but
       should not be used to verify specific intersection points.
 
-    - ``fill`` -- bool (default: ``True``), whether to color in the area
+    - ``fill`` -- boolean (default: ``True``); whether to color in the area
       between contour lines
 
     - ``cmap`` -- a colormap (default: ``'gray'``), the name of
@@ -269,25 +269,25 @@ def contour_plot(f, xrange, yrange, **options):
       is passed (or the option is not given), then the number of contour
       lines is determined automatically, and is usually about 5.
 
-    - ``linewidths`` -- integer or list of integer (default: None), if
+    - ``linewidths`` -- integer or list of integer (default: ``None``), if
       a single integer all levels will be of the width given,
       otherwise the levels will be plotted with the width in the order
       given.  If the list is shorter than the number of contours, then
       the widths will be repeated cyclically.
 
-    - ``linestyles`` -- string or list of strings (default: None), the
-      style of the lines to be plotted, one of: ``"solid"``, ``"dashed"``,
-      ``"dashdot"``, ``"dotted"``, respectively ``"-"``, ``"--"``,
-      ``"-."``, ``":"``.  If the list is shorter than the number of
+    - ``linestyles`` -- string or list of strings (default: ``None``), the
+      style of the lines to be plotted, one of: ``'solid'``, ``'dashed'``,
+      ``'dashdot'``, ``'dotted'``, respectively ``'-'``, ``'--'``,
+      ``'-.'``, ``':'``.  If the list is shorter than the number of
       contours, then the styles will be repeated cyclically.
 
-    - ``labels`` -- boolean (default: False) Show level labels or not.
+    - ``labels`` -- boolean (default: ``False``); show level labels or not
 
       The following options are to adjust the style and placement of
       labels, they have no effect if no labels are shown.
 
-      - ``label_fontsize`` -- integer (default: 9), the font size of
-        the labels.
+      - ``label_fontsize`` -- integer (default: 9); the font size of
+        the labels
 
       - ``label_colors`` -- string or sequence of colors (default:
         None) If a string, gives the name of a single color with which
@@ -295,40 +295,40 @@ def contour_plot(f, xrange, yrange, **options):
         labels.  A color is a string giving the name of one or a
         3-tuple of floats.
 
-      - ``label_inline`` -- boolean (default: False if fill is True,
+      - ``label_inline`` -- boolean (default: ``False`` if fill is True,
         otherwise True), controls whether the underlying contour is
         removed or not.
 
-      - ``label_inline_spacing`` -- integer (default: 3), When inline,
+      - ``label_inline_spacing`` -- integer (default: 3); when inline,
         this is the amount of contour that is removed from each side,
         in pixels.
 
-      - ``label_fmt`` -- a format string (default: "%1.2f"), this is
+      - ``label_fmt`` -- a format string (default: ``"%1.2f"``), this is
         used to get the label text from the level.  This can also be a
         dictionary with the contour levels as keys and corresponding
         text string labels as values.  It can also be any callable which
         returns a string when called with a numeric contour level.
 
-    - ``colorbar`` -- boolean (default: False) Show a colorbar or not.
+    - ``colorbar`` -- boolean (default: ``False``); show a colorbar or not
 
       The following options are to adjust the style and placement of
       colorbars.  They have no effect if a colorbar is not shown.
 
-      - ``colorbar_orientation`` -- string (default: 'vertical'),
+      - ``colorbar_orientation`` -- string (default: ``'vertical'``),
         controls placement of the colorbar, can be either 'vertical'
         or 'horizontal'
 
       - ``colorbar_format`` -- a format string, this is used to format
-        the colorbar labels.
+        the colorbar labels
 
-      - ``colorbar_spacing`` -- string (default: 'proportional').  If
+      - ``colorbar_spacing`` -- string (default: ``'proportional'``); if
         'proportional', make the contour divisions proportional to
         values.  If 'uniform', space the colorbar divisions uniformly,
         without regard for numeric values.
 
     - ``legend_label`` -- the label for this item in the legend
 
-    -  ``region`` - (default: None) If region is given, it must be a function
+    - ``region`` -- (default: ``None``) if region is given, it must be a function
         of two variables. Only segments of the surface where region(x,y)
         returns a number >0 will be included in the plot.
 
@@ -415,7 +415,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2,2), (-2,2))
         sphinx_plot(g)
 
@@ -427,7 +427,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2, 2), (-2, 2), contours=2, cmap=[(1,0,0), (0,1,0), (0,0,1)])
         sphinx_plot(g)
 
@@ -440,7 +440,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2,2), (-2,2), contours=(0.1,1.0,1.2,1.4), cmap='hsv')
         sphinx_plot(g)
 
@@ -452,7 +452,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2,2), (-2,2), contours=(1.0,), fill=False)
         sphinx_plot(g)
 
@@ -475,7 +475,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2,2), (-2,2), fill=False, linewidths=10)
         sphinx_plot(g)
 
@@ -488,7 +488,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2,2), (-2,2), fill=False, linestyles='dashdot')
         sphinx_plot(g)
 
@@ -667,7 +667,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (-2,2), (-2,2), labels=True, label_colors='red')
         sphinx_plot(g)
 
@@ -680,7 +680,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), colorbar=True)
         sphinx_plot(g)
 
@@ -692,7 +692,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), colorbar=True, colorbar_orientation='horizontal')
         sphinx_plot(g)
 
@@ -704,7 +704,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), contours=[-2,-1,4],
                         colorbar=True)
         sphinx_plot(g)
@@ -718,7 +718,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), contours=[-2,-1,4],
                          colorbar=True, colorbar_spacing='uniform')
         sphinx_plot(g)
@@ -732,7 +732,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), contours=[0,2,3,6],
                          colorbar=True, colorbar_format='%.3f')
         sphinx_plot(g)
@@ -747,7 +747,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), labels=True,
                          label_colors='red', contours=[0,2,3,6],
                          colorbar=True)
@@ -762,7 +762,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 + y**2
+        def f(x, y): return x**2 + y**2
         g = contour_plot(f, (x,-3,3), (y,-3,3), cmap='winter',
                          contours=20, fill=False, colorbar=True)
         sphinx_plot(g)
@@ -793,7 +793,7 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return cos(x) + sin(y)
+        def f(x, y): return cos(x) + sin(y)
         g = contour_plot(f, (0,pi), (0,pi), axes=True)
         sphinx_plot(g)
 
@@ -819,12 +819,12 @@ def contour_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return cos(x) + sin(y)
+        def f(x, y): return cos(x) + sin(y)
         g = contour_plot(f, (-pi,pi), (-pi,pi), fill=False, axes=True)
         sphinx_plot(g)
 
     If you are plotting a sole contour and if all of your data lie on
-    one side of it, then (as part of :trac:`21042`) a heuristic may be
+    one side of it, then (as part of :issue:`21042`) a heuristic may be
     used to improve the result; in that case, a warning is emitted::
 
         sage: contour_plot(lambda x,y: abs(x^2-y^2), (-1,1), (-1,1),
@@ -845,7 +845,7 @@ def contour_plot(f, xrange, yrange, **options):
         sphinx_plot(g)
 
     Constant functions (with a single contour) can be plotted as well;
-    this was not possible before :trac:`21042`::
+    this was not possible before :issue:`21042`::
 
         sage: contour_plot(lambda x,y: 0, (-1,1), (-1,1),
         ....:              contours=[0], fill=False, cmap=['blue'])
@@ -862,7 +862,7 @@ def contour_plot(f, xrange, yrange, **options):
 
     TESTS:
 
-    To check that :trac:`5221` is fixed, note that this has three curves, not
+    To check that :issue:`5221` is fixed, note that this has three curves, not
     two::
 
         sage: x,y = var('x,y')
@@ -870,17 +870,16 @@ def contour_plot(f, xrange, yrange, **options):
         ....:              contours=[-4,-2,0], fill=False)
         Graphics object consisting of 1 graphics primitive
 
-    Check that :trac:`18074` is fixed::
+    Check that :issue:`18074` is fixed::
 
         sage: contour_plot(0, (0,1), (0,1))
         ...Graphics object consisting of 1 graphics primitive
 
-    Domain points in :trac:`11648` with complex output are now skipped::
+    Domain points in :issue:`11648` with complex output are now skipped::
 
         sage: x,y = SR.var('x,y', domain='real')
         sage: contour_plot(log(x) + log(y), (-1, 5), (-1, 5))
         Graphics object consisting of 1 graphics primitive
-
     """
     from sage.plot.all import Graphics
     from sage.plot.misc import setup_for_eval_on_grid
@@ -891,7 +890,7 @@ def contour_plot(f, xrange, yrange, **options):
     F, ranges = setup_for_eval_on_grid(ev, [xrange, yrange],
                                        options['plot_points'])
     h = F[0]
-    xrange, yrange = [r[:2] for r in ranges]
+    xrange, yrange = (r[:2] for r in ranges)
 
     xy_data_array = [[h(x, y) for x in xsrange(*ranges[0],
                                                include_endpoint=True)]
@@ -950,7 +949,7 @@ def contour_plot(f, xrange, yrange, **options):
             # ...make it actually the const_z0 function.
             xy_data_array.fill(z0)
 
-            # We're going to set fill=True in a momemt, so we need to
+            # We're going to set fill=True in a moment, so we need to
             # prepend an entry to the cmap so that the user's original
             # cmap winds up in the right place.
             if "cmap" in options:
@@ -1000,7 +999,7 @@ def contour_plot(f, xrange, yrange, **options):
                 F, ranges = setup_for_eval_on_grid(ev, [xrange, yrange],
                                                    options['plot_points'])
                 h = F[0]
-                xrange, yrange = [r[:2] for r in ranges]
+                xrange, yrange = (r[:2] for r in ranges)
 
                 # ...and a function whose values are shifted towards
                 # z0 by "tol".
@@ -1046,10 +1045,10 @@ def implicit_plot(f, xrange, yrange, **options):
 
     - ``f`` -- a function of two variables or equation in two variables
 
-    - ``(xmin,xmax)`` -- 2-tuple, the range of ``x``
+    - ``(xmin, xmax)`` -- 2-tuple, the range of ``x``
       values or ``(x,xmin,xmax)``
 
-    - ``(ymin,ymax)`` -- 2-tuple, the range of ``y``
+    - ``(ymin, ymax)`` -- 2-tuple, the range of ``y``
       values or ``(y,ymin,ymax)``
 
     The following inputs must all be passed in as named parameters:
@@ -1058,21 +1057,21 @@ def implicit_plot(f, xrange, yrange, **options):
       in each direction of the grid
 
     - ``fill`` -- boolean (default: ``False``); if ``True``, fill the region
-      `f(x, y) < 0`.
+      `f(x, y) < 0`
 
-    - ``fillcolor`` -- string (default: ``'blue'``), the color of the region
+    - ``fillcolor`` -- string (default: ``'blue'``); the color of the region
       where `f(x,y) < 0` if ``fill = True``. Colors are defined in
       :mod:`sage.plot.colors`; try ``colors?`` to see them all.
 
-    - ``linewidth`` -- integer (default: None), if a single integer all levels
+    - ``linewidth`` -- integer (default: ``None``); if a single integer all levels
       will be of the width given, otherwise the levels will be plotted with the
       widths in the order given.
 
-    - ``linestyle`` -- string (default: None), the style of the line to be
-      plotted, one of: ``"solid"``, ``"dashed"``, ``"dashdot"`` or
-      ``"dotted"``, respectively ``"-"``, ``"--"``, ``"-."``, or ``":"``.
+    - ``linestyle`` -- string (default: ``None``); the style of the line to be
+      plotted, one of: ``'solid'``, ``'dashed'``, ``'dashdot'`` or
+      ``'dotted'``, respectively ``'-'``, ``'--'``, ``'-.'``, or ``':'``.
 
-    - ``color`` -- string (default: ``'blue'``), the color of the plot. Colors
+    - ``color`` -- string (default: ``'blue'``); the color of the plot. Colors
       are defined in :mod:`sage.plot.colors`; try ``colors?`` to see them all.
       If ``fill = True``, then this sets only the color of the border of the
       plot. See ``fillcolor`` for setting the color of the fill region.
@@ -1085,17 +1084,17 @@ def implicit_plot(f, xrange, yrange, **options):
       ``basex`` sets the base of the logarithm along the horizontal
       axis and ``basey`` sets the base along the vertical axis.
 
-    - ``scale`` -- (default: ``"linear"``) string. The scale of the axes.
-      Possible values are ``"linear"``, ``"loglog"``, ``"semilogx"``,
-      ``"semilogy"``.
+    - ``scale`` -- (default: ``'linear'``) string. The scale of the axes.
+      Possible values are ``'linear'``, ``'loglog'``, ``'semilogx'``,
+      ``'semilogy'``.
 
       The scale can be also be given as single argument that is a list
       or tuple ``(scale, base)`` or ``(scale, basex, basey)``.
 
-      The ``"loglog"`` scale sets both the horizontal and vertical axes to
-      logarithmic scale. The ``"semilogx"`` scale sets the horizontal axis
-      to logarithmic scale. The ``"semilogy"`` scale sets the vertical axis
-      to logarithmic scale. The ``"linear"`` scale is the default value
+      The ``'loglog'`` scale sets both the horizontal and vertical axes to
+      logarithmic scale. The ``'semilogx'`` scale sets the horizontal axis
+      to logarithmic scale. The ``'semilogy'`` scale sets the vertical axis
+      to logarithmic scale. The ``'linear'`` scale is the default value
       when :class:`~sage.plot.graphics.Graphics` is initialized.
 
     .. WARNING::
@@ -1133,7 +1132,7 @@ def implicit_plot(f, xrange, yrange, **options):
 
     .. PLOT::
 
-        def f(x,y): return x**2 + y**2 - 2
+        def f(x, y): return x**2 + y**2 - 2
         g = implicit_plot(f, (-3,3), (-3,3), fill=True, plot_points=500)
         sphinx_plot(g)
 
@@ -1144,7 +1143,7 @@ def implicit_plot(f, xrange, yrange, **options):
 
     .. PLOT::
 
-        def f(x,y): return x**2 + y**2 - 2
+        def f(x, y): return x**2 + y**2 - 2
         g = implicit_plot(f, (-3,3), (-3,3), linewidth=6)
         sphinx_plot(g)
 
@@ -1156,7 +1155,7 @@ def implicit_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x, y =var("x y")
-        def f(x,y): return x**2 + y**2 - 2
+        def f(x, y): return x**2 + y**2 - 2
         g = implicit_plot(f, (-3,3), (-3,3), linestyle='dashdot')
         sphinx_plot(g)
 
@@ -1169,7 +1168,7 @@ def implicit_plot(f, xrange, yrange, **options):
 
     .. PLOT::
 
-        def f(x,y): return x**2 + y**2 - 2
+        def f(x, y): return x**2 + y**2 - 2
         g = implicit_plot(f, (-3,3), (-3,3), color='red', fill=True, fillcolor='green',
                                              plot_points=500)
         sphinx_plot(g)
@@ -1189,13 +1188,13 @@ def implicit_plot(f, xrange, yrange, **options):
 
     You can even change the color of the plot::
 
-        sage: implicit_plot(x^2 + y^2 == 2, (x,-3,3), (y,-3,3), color="red")
+        sage: implicit_plot(x^2 + y^2 == 2, (x,-3,3), (y,-3,3), color='red')
         Graphics object consisting of 1 graphics primitive
 
     .. PLOT::
 
         x, y =var("x y")
-        g = implicit_plot(x**2 + y**2 == 2, (x,-3,3), (y,-3,3), color="red")
+        g = implicit_plot(x**2 + y**2 == 2, (x,-3,3), (y,-3,3), color='red')
         sphinx_plot(g)
 
     The color of the fill region can be changed::
@@ -1206,7 +1205,7 @@ def implicit_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x, y =var("x y")
-        g = implicit_plot(x**2 + y**2 == 2, (x,-3,3), (y,-3,3), fill=True, fillcolor="red")
+        g = implicit_plot(x**2 + y**2 == 2, (x,-3,3), (y,-3,3), fill=True, fillcolor='red')
         sphinx_plot(g)
 
     Here is a beautiful (and long) example which also tests that all
@@ -1238,7 +1237,7 @@ def implicit_plot(f, xrange, yrange, **options):
         ....:     z = 0
         ....:     for i in range(n):
         ....:         z = z*z + c
-        ....:     def f(x,y):
+        ....:     def f(x, y):
         ....:         val = z(CDF(x, y))
         ....:         return val.norm() - 4
         ....:     return f
@@ -1255,7 +1254,7 @@ def implicit_plot(f, xrange, yrange, **options):
              z = 0
              for i in range(n):
                  z = z*z + c
-             def f(x,y):
+             def f(x, y):
                  val = z(CDF(x, y))
                  return val.norm() - 4
              return f
@@ -1274,7 +1273,7 @@ def implicit_plot(f, xrange, yrange, **options):
              z = 0
              for i in range(n):
                  z = z*z + c
-             def f(x,y):
+             def f(x, y):
                  val = z(CDF(x, y))
                  return val.norm() - 4
              return f
@@ -1297,7 +1296,7 @@ def implicit_plot(f, xrange, yrange, **options):
              z = 0
              for i in range(n):
                  z = z*z + c
-             def f(x,y):
+             def f(x, y):
                  val = z(CDF(x, y))
                  return val.norm() - 4
              return f
@@ -1339,7 +1338,7 @@ def implicit_plot(f, xrange, yrange, **options):
         ...
         ValueError: fill=5 is not supported
 
-    To check that :trac:`9654` is fixed::
+    To check that :issue:`9654` is fixed::
 
         sage: f(x,y) = x^2 + y^2 - 2
         sage: implicit_plot(f, (-3,3), (-3,3), rgbcolor=(1,0,0))
@@ -1394,27 +1393,26 @@ def implicit_plot(f, xrange, yrange, **options):
 @options(plot_points=100, incol='blue', outcol=None, bordercol=None,
          borderstyle=None, borderwidth=None, frame=False, axes=True,
          legend_label=None, aspect_ratio=1, alpha=1)
-def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
-                borderstyle, borderwidth, alpha, **options):
+def region_plot(f, xrange, yrange, **options):
     r"""
     ``region_plot`` takes a boolean function of two variables, `f(x, y)`
-    and plots the region where f is True over the specified
+    and plots the region where f is ``True`` over the specified
     ``xrange`` and ``yrange`` as demonstrated below.
 
     ``region_plot(f, (xmin,xmax), (ymin,ymax), ...)``
 
     INPUT:
 
-    - ``f`` -- a boolean function or a list of boolean functions of
+    - ``f`` -- boolean function or a list of boolean functions of
       two variables
 
-    - ``(xmin,xmax)`` -- 2-tuple, the range of ``x`` values OR 3-tuple
+    - ``(xmin, xmax)`` -- 2-tuple, the range of ``x`` values OR 3-tuple
       ``(x,xmin,xmax)``
 
-    - ``(ymin,ymax)`` -- 2-tuple, the range of ``y`` values OR 3-tuple
+    - ``(ymin, ymax)`` -- 2-tuple, the range of ``y`` values OR 3-tuple
       ``(y,ymin,ymax)``
 
-    - ``plot_points``  -- integer (default: 100); number of points to plot
+    - ``plot_points`` -- integer (default: 100); number of points to plot
       in each direction of the grid
 
     - ``incol`` -- a color (default: ``'blue'``), the color inside the region
@@ -1430,11 +1428,11 @@ def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
        (``'black'`` if ``borderwidth`` or ``borderstyle`` is specified but
        not ``bordercol``)
 
-    - ``borderstyle``  -- string (default: ``'solid'``), one of ``'solid'``,
+    - ``borderstyle`` -- string (default: ``'solid'``); one of ``'solid'``,
       ``'dashed'``, ``'dotted'``, ``'dashdot'``, respectively ``'-'``,
-      ``'--'``, ``':'``, ``'-.'``.
+      ``'--'``, ``':'``, ``'-.'``
 
-    - ``borderwidth``  -- integer (default: ``None``), the width of the
+    - ``borderwidth`` -- integer (default: ``None``); the width of the
       border in pixels
 
     - ``alpha`` -- (default: 1) how transparent the fill is; a number
@@ -1442,26 +1440,25 @@ def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
 
     - ``legend_label`` -- the label for this item in the legend
 
-    - ``base`` - (default: 10) the base of the logarithm if
+    - ``base`` -- (default: 10) the base of the logarithm if
       a logarithmic scale is set. This must be greater than 1. The base
       can be also given as a list or tuple ``(basex, basey)``.
       ``basex`` sets the base of the logarithm along the horizontal
       axis and ``basey`` sets the base along the vertical axis.
 
-    - ``scale`` -- (default: ``"linear"``) string. The scale of the axes.
-      Possible values are ``"linear"``, ``"loglog"``, ``"semilogx"``,
-      ``"semilogy"``.
+    - ``scale`` -- string (default: ``'linear'``); the scale of the axes.
+      Possible values are ``'linear'``, ``'loglog'``, ``'semilogx'``,
+      ``'semilogy'``.
 
       The scale can be also be given as single argument that is a list
       or tuple ``(scale, base)`` or ``(scale, basex, basey)``.
 
-      The ``"loglog"`` scale sets both the horizontal and vertical axes to
-      logarithmic scale. The ``"semilogx"`` scale sets the horizontal axis
-      to logarithmic scale. The ``"semilogy"`` scale sets the vertical axis
-      to logarithmic scale. The ``"linear"`` scale is the default value
+      The ``'loglog'`` scale sets both the horizontal and vertical axes to
+      logarithmic scale. The ``'semilogx'`` scale sets the horizontal axis
+      to logarithmic scale. The ``'semilogy'`` scale sets the vertical axis
+      to logarithmic scale. The ``'linear'`` scale is the default value
       when :class:`~sage.plot.graphics.Graphics` is initialized.
 
-
     EXAMPLES:
 
     Here we plot a simple function of two variables::
@@ -1637,7 +1634,7 @@ def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
 
     TESTS:
 
-    To check that :trac:`16907` is fixed::
+    To check that :issue:`16907` is fixed::
 
         sage: x, y = var('x, y')
         sage: disc1 = region_plot(x^2 + y^2 < 1, (x,-1,1), (y,-1,1), alpha=0.5)
@@ -1645,7 +1642,7 @@ def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
         sage: disc1 + disc2
         Graphics object consisting of 2 graphics primitives
 
-    To check that :trac:`18286` is fixed::
+    To check that :issue:`18286` is fixed::
 
         sage: x, y = var('x, y')
         sage: region_plot([x == 0], (x,-1,1), (y,-1,1))
@@ -1659,6 +1656,14 @@ def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
     from warnings import warn
     import numpy
 
+    plot_points = options['plot_points']
+    incol = options.pop('incol')
+    outcol = options.pop('outcol')
+    bordercol = options.pop('bordercol')
+    borderstyle = options.pop('borderstyle')
+    borderwidth = options.pop('borderwidth')
+    alpha = options.pop('alpha')
+
     if not isinstance(f, (list, tuple)):
         f = [f]
 
@@ -1677,13 +1682,13 @@ def region_plot(f, xrange, yrange, plot_points, incol, outcol, bordercol,
     if neqs and not bordercol:
         bordercol = incol
     if not f:
-        return implicit_plot(feqs[0], xrange, yrange, plot_points=plot_points,
-                             fill=False, linewidth=borderwidth,
-                             linestyle=borderstyle, color=bordercol, **options)
+        return implicit_plot(feqs[0], xrange, yrange, fill=False,
+                             linewidth=borderwidth, linestyle=borderstyle,
+                             color=bordercol, **options)
     f_all, ranges = setup_for_eval_on_grid(feqs + f,
                                            [xrange, yrange],
                                            plot_points)
-    xrange, yrange = [r[:2] for r in ranges]
+    xrange, yrange = (r[:2] for r in ranges)
 
     xy_data_arrays = numpy.asarray([[[func(x, y)
                                       for x in xsrange(*ranges[0],
