@@ -571,7 +571,7 @@ class DrinfeldModule_finite(DrinfeldModule):
         Instead, use :meth:`frobenius_charpoly` with the option
         `algorithm='gekeler'`.
 
-        .. WARNING:
+        .. WARNING::
 
             This algorithm only works in the generic case when the
             corresponding linear system is invertible. Notable cases
@@ -620,7 +620,7 @@ class DrinfeldModule_finite(DrinfeldModule):
             block_shifts.append(block_shifts[-1] + shifts[i])
         # Compute the images \phi_T^i for i = 0 .. n.
         gen_powers = [self(A.gen()**i).coefficients(sparse=False)
-                      for i in range(0, n + 1)]
+                      for i in range(n + 1)]
         sys, vec = Matrix(K, rows, cols), vector(K, rows)
         vec[rows - 1] = -1
         for j in range(r):
